@@ -3,8 +3,9 @@
 import logging
 import os
 import re
+from datetime import date
 from functools import wraps
-from pathlib import PurePath
+from pathlib import Path, PurePath
 from typing import Optional, Tuple
 from urllib.parse import urlsplit
 
@@ -154,6 +155,46 @@ def commit_new_version(version: str):
     return repo.git.commit(m=message, author=commit_author)
 
 
+@check_repo
+@LoggedFunction(logger)
+def update_changelog_file(version: str, content_to_add: str):
+    """
+    Update changelog file with changelog for the release.
+
+    :param version: The release version number, as a string.
+    :param content_to_add: The release notes for the version.
+    """
+    changelog_file = config.get("changelog_file")
+    changelog_placeholder = config.get("changelog_placeholder")
+    git_path = Path(os.getcwd(), changelog_file)
+    if not git_path.exists():
+        original_content = f"# Changelog\n\n{changelog_placeholder}\n"
+        logger.warning(f"Changelog file not found: {git_path} - creating it.")
+    else:
+        original_content = git_path.read_text()
+
+    if changelog_placeholder not in original_content:
+        logger.warning(
+            f"Placeholder '{changelog_placeholder}' not found "
+            f"in changelog file {git_path} - skipping change."
+        )
+        return
+
+    updated_content = original_content.replace(
+        changelog_placeholder,
+        "\n".join(
+            [
+                changelog_placeholder,
+                "",
+                f"## v{version} ({date.today():%Y-%m-%d})",
+                content_to_add,
+            ]
+        ),
+    )
+    git_path.write_text(updated_content)
+    repo.git.add(str(git_path.relative_to(repo.working_dir)))
+
+
 @check_repo
 @LoggedFunction(logger)
 def tag_new_version(version: str):
